@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov, TestFlows Test Framework (http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,10 +12,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-__author__ = "Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)"
-__version__ = "1.3.200421.1170112"
+__author__ = "Vitaliy Zakaznikov"
+__version__ = "1.6.200909.1205435"
 __license__ = f"""
-Copyright 2019 {__author__}
+Copyright 2019 Katteli Inc.
+TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -28,4 +30,4 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License
 """
-from .shell import *
\ No newline at end of file
+from .shell import *
